@@ -62,58 +62,35 @@ pml_chart <- function(x, value, id_x, id_y){
 }
 
 #' @export
-#' @importFrom stats setNames
-#' @importFrom writexl write_xlsx
-#' @importFrom xml2 read_xml xml_find_first xml_replace as_xml_document xml_add_child write_xml
 #' @title add chart into a PowerPoint slide
 #' @description add a chart as a new shape in the current slide.
-#' These functions will be deprecated
-#' in the next release and function \code{\link{ph_with.ms_chart}} should
-#' be used instead.#' @param x an rpptx object
-#' @param x a pptx device
+#' These functions are deprecated, function \code{\link{ph_with.ms_chart}} should
+#' be used instead.
+#' @param x an rpptx object
 #' @param chart \code{ms_chart} object
 #' @param type placeholder type
 #' @param index placeholder index (integer). This is to be used when a placeholder type
 #' is not unique in the current slide, e.g. two placeholders with type 'body'.
-#' @importFrom officer ph_from_xml
-#' @examples
-#' my_barchart <- ms_barchart(data = browser_data,
-#'   x = "browser", y = "value", group = "serie")
-#' my_barchart <- chart_settings( x = my_barchart,
-#'   dir="vertical", grouping="clustered", gap_width = 50 )
-#' my_barchart <- chart_ax_x( x= my_barchart,
-#'   cross_between = 'between', major_tick_mark="out")
-#' my_barchart <- chart_ax_y( x= my_barchart,
-#'   cross_between = "midCat", major_tick_mark="in")
-#'
-#' \donttest{
-#' library(officer)
-#' doc <- read_pptx()
-#' doc <- add_slide(doc, layout = "Title and Content", master = "Office Theme")
-#' doc <- ph_with_chart(doc, chart = my_barchart)
-#'
-#' fileout <- tempfile(fileext = ".pptx")
-#' print(doc, target = fileout)
-#' }
+#' @importFrom officer ph_location_type
 ph_with_chart <- function( x, chart, type = "body", index = 1 ){
-  stopifnot(inherits(x, "rpptx"))
-  graphic_frame <- pml_chart(x, chart, id_x = "64451712", id_y = "64453248")
-  x$content_type$add_ext(extension = "xlsx", type = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet")
-  ph_from_xml(x = x, value = graphic_frame, type = type, index = index )
+  .Deprecated("ph_with")
+  ph_with(x, chart, location = ph_location_type(type = type, id = index))
 }
 
 #' @export
 #' @param left,top location of chart on the slide
 #' @param height,width Height and width in inches.
 #' @rdname ph_with_chart
-#' @importFrom officer ph_from_xml_at
+#' @importFrom officer ph_location
 ph_with_chart_at <- function( x, chart, left, top, width, height ){
-  stopifnot(inherits(x, "rpptx"))
-  graphic_frame <- pml_chart(x, chart, id_x = "64451712", id_y = "64453248")
-  x$content_type$add_ext(extension = "xlsx", type = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet")
-  ph_from_xml_at(x = x, value = graphic_frame, left = left, top = top, width = width, height = height )
+  .Deprecated("ph_with")
+  ph_with(x, chart, location = ph_location(left = left, top = top, width = width, height = height))
+
 }
 
+#' @importFrom stats setNames
+#' @importFrom writexl write_xlsx
+#' @importFrom xml2 read_xml xml_find_first xml_replace as_xml_document xml_add_child write_xml
 #' @importFrom officer ph_with
 #' @importFrom xml2 as_xml_document
 #' @export
@@ -123,8 +100,8 @@ ph_with_chart_at <- function( x, chart, left, top, width, height ){
 #' by \code{\link[officer]{read_pptx}}.
 #' @param x a pptx device
 #' @param value chart object
-#' @param ... Arguments to be passed to methods, argument
-#' \code{location} is mandatory.
+#' @param location a location for a placeholder.
+#' @param ... Arguments to be passed to methods.
 #' @examples
 #' my_barchart <- ms_barchart(data = browser_data,
 #'   x = "browser", y = "value", group = "serie")
@@ -142,9 +119,9 @@ ph_with_chart_at <- function( x, chart, left, top, width, height ){
 #'
 #' fileout <- tempfile(fileext = ".pptx")
 #' print(doc, target = fileout)
-ph_with.ms_chart <- function( x, value, ... ){
+ph_with.ms_chart <- function( x, value, location, ... ){
   stopifnot(inherits(x, "rpptx"))
   graphic_frame <- pml_chart(x, value, id_x = "64451712", id_y = "64453248")
   x$content_type$add_ext(extension = "xlsx", type = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet")
-  ph_with(x = x, value = as_xml_document(graphic_frame), ... )
+  ph_with(x = x, value = as_xml_document(graphic_frame), location = location, ... )
 }
