@@ -26,7 +26,7 @@ my_barchart <- ms_barchart(data = browser_data,
 library(officer)
 doc <- read_pptx()
 doc <- add_slide(doc, layout = "Title and Content", master = "Office Theme")
-doc <- ph_with_chart(doc, chart = my_barchart)
+doc <- ph_with(doc, value = my_barchart, location = ph_location_fullsize())
 print(doc, target = "assets/pptx/barchart_01_stacked.pptx")
 
 ## ----echo=FALSE----------------------------------------------------------
@@ -34,7 +34,7 @@ office_doc_link( url = paste0( "https://ardata-fr.github.io/mschart/articles/",
 
 ## ----results='hide'------------------------------------------------------
 doc <- read_docx()
-doc <- body_add_chart(doc, chart = my_barchart, style = "centered")
+doc <- body_add_chart(doc, chart = my_barchart, style = "Normal")
 print(doc, target = "assets/docx/barchart_01_stacked.docx")
 
 ## ----echo=FALSE----------------------------------------------------------
